@@ -1,11 +1,12 @@
+""" Calls a function in a local app, without needing to use rekuest or fakts."""
+from click import Context
 import rich_click as click
 from arkitekt_next.cli.options import *
 import asyncio
 from arkitekt_next.cli.ui import construct_run_panel
 from importlib import import_module
 from arkitekt_next.cli.utils import import_builder
-from rekuest_next.api.schema import NodeKind, BindsInput
-from rich.table import Table
+from rekuest_next.rekuest import RekuestNext
 from rich.console import Console
 from typing import Dict, Any
 
@@ -16,14 +17,23 @@ async def call_app(
     template_string: str,
     arg: Dict[str, Any],
 ):
+    
+
+
     async with app:
-        raise NotImplementedError("Not implemented yet")
+
+        rekuest: RekuestNext = app.rekuest
+        
+        raise NotImplementedError("Not implemented yet. Do you want to implement it? :)")
+
+
+
 
 
 @click.command("prod")
 @click.option(
     "--url",
-    help="The fakts url for connection",
+    help="The fakts_next url for connection",
     default=DEFAULT_ARKITEKT_URL,
     envvar="FAKTS_URL",
 )
@@ -48,13 +58,16 @@ async def call_app(
     "template",
     help="The template to run",
     type=str,
+    required=True,
 )
+@click.option("--fakts", "-f", "fakts", type=(str, str), multiple=True)
 def local(
-    ctx,
-    entrypoint=None,
-    builder=None,
-    args=None,
-    template: str = None,
+    ctx: Context,
+    entrypoint: str | None =None,
+    builder: str | None =None,
+    args: Optional[Dict[str, Any]] = None,
+    template: str | None = None,
+    fakts: Optional[Dict[str, str]] = None,
     **builder_kwargs,
 ):
     """Runs the app in production mode
@@ -68,6 +81,8 @@ def local(
     console = get_console(ctx)
     entrypoint = entrypoint or manifest.entrypoint
 
+
+    fakts = dict(fakts) if fakts else None
     kwargs = dict(args or [])
 
     builder = import_builder(builder)
@@ -82,7 +97,9 @@ def local(
     app = builder(
         **manifest.to_builder_dict(),
         **builder_kwargs,
+        fakts=fakts,
     )
+    
 
     panel = construct_run_panel(app)
     console.print(panel)
