@@ -1,6 +1,7 @@
+from arkitekt_next import get_default_service_registry
 import rich_click as click
 from importlib import import_module
-from arkitekt_next.apps.types import App
+from arkitekt_next.app.app import App
 from arkitekt_next.cli.commands.run.utils import import_builder
 from arkitekt_next.cli.vars import get_console, get_manifest
 from arkitekt_next.cli.options import with_builder
@@ -29,12 +30,10 @@ async def run_app(app):
     is_flag=True,
     default=False,
 )
-@with_builder
 def requirements(
     ctx,
     pretty: bool,
     machine_readable: bool,
-    builder: str = "arkitekt_next.builders.easy",
 ):
     """Checks the requirements of the app
 
@@ -49,8 +48,6 @@ def requirements(
     entrypoint_file = f"{manifest.entrypoint}.py"
     os.path.realpath(entrypoint_file)
 
-    builder_func = import_builder(builder)
-
     entrypoint = manifest.entrypoint
 
     with console.status("Loading entrypoint module..."):
@@ -60,16 +57,10 @@ def requirements(
             console.print(f"Could not find entrypoint module {entrypoint}")
             raise e
 
-    app: App = builder_func(
-        identifier=identifier,
-        version="dev",
-        logo=manifest.logo,
-    )
+    service_registry = get_default_service_registry()
+
+    x = [item.model_dump(by_alias=True) for item in service_registry.get_requirements()]
 
-    x = [
-        item.model_dump(by_alias=True)
-        for item in app.manifest.requirements
-    ]
     if machine_readable:
         print("--START_REQUIREMENTS--" + json.dumps(x) + "--END_REQUIREMENTS--")
 
