@@ -1,18 +1,21 @@
+import sys
 import rich_click as click
 from arkitekt_next.cli.vars import get_console, get_manifest
 import os
 from rich.panel import Panel
 import subprocess
 import uuid
-from arkitekt_next.cli.io import generate_build
+
+from kabinet.api.schema import RequirementInput
+from .io import generate_build
 from click import Context
-from arkitekt_next.cli.types import Flavour, InspectionInput
+from .types import Flavour, InspectionInput
 import yaml
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 import json
-from arkitekt_next.base_models import Requirement
+from arkitekt_next.constants import DEFAULT_ARKITEKT_URL
 from arkitekt_next.utils import create_arkitekt_next_folder
-from rekuest_next.api.schema import TemplateInput
+from rekuest_next.api.schema import ImplementationInput
 
 
 class InspectionError(Exception):
@@ -91,19 +94,63 @@ def inspect_docker_container(build_id: str) -> InspectionInput:
         raise InspectionError(f"An error occurred: {e.stdout + e.stderr}") from e
 
 
-def inspect_templates(build_id: str) -> list[TemplateInput]:
+def inspect_implementations(build_id: str, url: str) -> list[ImplementationInput]:
     try:
         # Run 'docker inspect' with the container ID or name
-        result = subprocess.run(
-            ["docker", "run", build_id, "arkitekt-next", "inspect", "templates", "-mr"],
+        process = subprocess.Popen(
+            " ".join(
+                [
+                    "docker",
+                    "run",
+                    "-it",
+                    "--network",
+                    "host",
+                    build_id,
+                    "arkitekt-next",
+                    "inspect",
+                    "implementations",
+                    "-mr",
+                ]
+            ),
+            shell=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
-            check=True,
-            text=True,
         )
 
+        lines: list[str] = []
+        # Poll process for new output until finished
+        while True:
+            if process.poll() is not None:
+                break
+            nextline = process.stdout.readline()
+
+            lines.append(nextline.decode("utf-8"))
+            sys.stdout.buffer.write(nextline)
+            sys.stdout.flush()
+
+        output = process.communicate()[0]
+        exitCode = process.returncode
+        result = "\n".join(lines)
+
+        
+        
+        if exitCode != 0:
+            
+            if "ModuleNotFoundError" in result:
+                raise click.ClickException(
+                    " It looks like you are missing a module in your container. Please make sure that you have all the dependencies installed in your container. The error is listed above."
+                )
+            
+            
+            
+            
+            raise click.ClickException(
+                "When running the command `arkitekt_next inspect implementations` we got an error. The error is listed above."
+            )
+
+        
         # Parse the JSON output
-        correct_part = result.stdout.split("--START_TEMPLATES--")[1].split(
+        correct_part = result.split("--START_TEMPLATES--")[1].split(
             "--END_TEMPLATES--"
         )[0]
 
@@ -115,20 +162,20 @@ def inspect_templates(build_id: str) -> list[TemplateInput]:
                 f"Could not decode JSON output of docker inspect. {combined_error}"
             ) from e
 
-        return list(output.values())
+        return output
     except subprocess.CalledProcessError as e:
         combined_error = e.stdout + e.stderr
 
         if "No such command" in combined_error:
             raise InspectionError(
-                "Could not find the command `arkitekt_next inspect definitions` in the container. Maybe"
+                "Could not find the command `arkitekt_next inspect implementations` in the container. Maybe"
                 + "you forgot to install arkitekt_next in the container? "
             )
 
         raise InspectionError(f"An error occurred: {e.stdout + e.stderr}") from e
 
 
-def inspect_requirements(build_id: str) -> Dict[str, Requirement]:
+def inspect_requirements(build_id: str) -> List[RequirementInput]:
     try:
         # Run 'docker inspect' with the container ID or name
         result = subprocess.run(
@@ -173,12 +220,12 @@ def inspect_requirements(build_id: str) -> Dict[str, Requirement]:
         raise InspectionError(f"An error occurred: {e.stdout + e.stderr}") from e
 
 
-def inspect_build(build_id: str) -> InspectionInput:
+def inspect_build(build_id: str, url: str) -> InspectionInput:
     size, size_root_fs = inspect_docker_container(build_id)
-    templates = inspect_templates(build_id)
+    implementations = inspect_implementations(build_id, url)
     requirements = inspect_requirements(build_id)
 
-    return InspectionInput(size=size, templates=templates, requirements=requirements)
+    return InspectionInput(size=size, implementations=tuple(implementations), requirements=tuple(requirements))
 
 
 def get_flavours(ctx: Context, select: Optional[str] = None) -> Dict[str, Flavour]:
@@ -193,7 +240,7 @@ def get_flavours(ctx: Context, select: Optional[str] = None) -> Dict[str, Flavou
             "We could not find the flavours folder. Please run `arkitekt_next port init` first to create a buildable flavour"
         )
 
-    flavours = {}
+    flavours: Dict[str, Flavour] = {}
 
     for dir_name in os.listdir(flavours_folder):
         dir = os.path.join(flavours_folder, dir_name)
@@ -205,7 +252,7 @@ def get_flavours(ctx: Context, select: Optional[str] = None) -> Dict[str, Flavou
                 with open(os.path.join(dir, "config.yaml")) as f:
                     valued = yaml.load(f, Loader=yaml.SafeLoader)
                 try:
-                    flavour = Flavour(**valued)
+                    flavour = Flavour.model_validate(valued)
                     flavour.check_relative_paths(dir)
                     flavours[dir_name] = flavour
 
@@ -233,8 +280,29 @@ def get_flavours(ctx: Context, select: Optional[str] = None) -> Dict[str, Flavou
     is_flag=True,
     default=False,
 )
+@click.option(
+    "--tag",
+    "-t",
+    help="Tag the build with a specific tag",
+    type=str,
+    default=None,
+    required=False,
+)
+@click.option(
+    "--url",
+    "-u",
+    help="The fakts_next server to use",
+    type=str,
+    default=DEFAULT_ARKITEKT_URL,
+)
 @click.pass_context
-def build(ctx: Context, flavour: str, no_inspect: bool) -> None:
+def build(
+    ctx: Context,
+    flavour: str,
+    no_inspect: bool,
+    tag: str | None = None,
+    url: str = DEFAULT_ARKITEKT_URL,
+) -> None:
     """Builds the arkitekt_next app to docker"""
 
     manifest = get_manifest(ctx)
@@ -252,7 +320,7 @@ def build(ctx: Context, flavour: str, no_inspect: bool) -> None:
 
     build_run = str(uuid.uuid4())
 
-    for key, flavour in flavours.items():
+    for key, inspected_flavour in flavours.items():
         md = Panel(
             "Building Flavour [bold]{}[/bold]".format(key),
             subtitle="This may take a while...",
@@ -260,13 +328,16 @@ def build(ctx: Context, flavour: str, no_inspect: bool) -> None:
         )
         console.print(md)
 
-        build_tag = build_flavour(key, flavour)
+        build_tag = build_flavour(key, inspected_flavour)
+
+        if tag:
+            subprocess.run(["docker", "tag", build_tag, tag], check=True)
 
         inspection = None
         if not no_inspect:
-            inspection = inspect_build(build_tag)
+            inspection = inspect_build(build_tag, url)
 
-        generate_build(build_run, build_tag, key, flavour, manifest, inspection)
+        generate_build(build_run, build_tag, key, inspected_flavour, manifest, inspection)
 
         md = Panel(
             "Built Flavour [bold]{}[/bold]".format(key),
